==> zio-aws-sagemaker_3-5.17.148.1-sources.jar: zio/aws/sagemaker/model/DescribePipelineResponse.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import zio.aws.sagemaker.model.primitives.{
  RoleArn,
  PipelineDescription,
  Timestamp,
  PipelineDefinition,
  PipelineArn,
  PipelineName
}
import scala.jdk.CollectionConverters.*
final case class DescribePipelineResponse(
    pipelineArn: Option[PipelineArn] = None,
    pipelineName: Option[PipelineName] = None,
    pipelineDisplayName: Option[PipelineName] = None,
    pipelineDefinition: Option[PipelineDefinition] = None,
    pipelineDescription: Option[PipelineDescription] = None,
    roleArn: Option[RoleArn] = None,
    pipelineStatus: Option[zio.aws.sagemaker.model.PipelineStatus] = None,
    creationTime: Option[Timestamp] = None,
    lastModifiedTime: Option[Timestamp] = None,
    lastRunTime: Option[Timestamp] = None,
    createdBy: Option[zio.aws.sagemaker.model.UserContext] = None,
    lastModifiedBy: Option[zio.aws.sagemaker.model.UserContext] = None,
    parallelismConfiguration: Option[
      zio.aws.sagemaker.model.ParallelismConfiguration
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.DescribePipelineResponse = {
    import DescribePipelineResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.DescribePipelineResponse
      .builder()
      .optionallyWith(
        pipelineArn.map(value => PipelineArn.unwrap(value): java.lang.String)
      )(_.pipelineArn)
      .optionallyWith(
        pipelineName.map(value => PipelineName.unwrap(value): java.lang.String)
      )(_.pipelineName)
      .optionallyWith(
        pipelineDisplayName.map(value =>
          PipelineName.unwrap(value): java.lang.String
        )
      )(_.pipelineDisplayName)
      .optionallyWith(
        pipelineDefinition.map(value =>
          PipelineDefinition.unwrap(value): java.lang.String
        )
      )(_.pipelineDefinition)
      .optionallyWith(
        pipelineDescription.map(value =>
          PipelineDescription.unwrap(value): java.lang.String
        )
      )(_.pipelineDescription)
      .optionallyWith(
        roleArn.map(value => RoleArn.unwrap(value): java.lang.String)
      )(_.roleArn)
      .optionallyWith(pipelineStatus.map(value => value.unwrap))(
        _.pipelineStatus
      )
      .optionallyWith(
        creationTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.creationTime)
      .optionallyWith(
        lastModifiedTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.lastModifiedTime)
      .optionallyWith(
        lastRunTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.lastRunTime)
      .optionallyWith(createdBy.map(value => value.buildAwsValue()))(
        _.createdBy
      )
      .optionallyWith(lastModifiedBy.map(value => value.buildAwsValue()))(
        _.lastModifiedBy
      )
      .optionallyWith(
        parallelismConfiguration.map(value => value.buildAwsValue())
      )(_.parallelismConfiguration)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.DescribePipelineResponse.ReadOnly =
    zio.aws.sagemaker.model.DescribePipelineResponse.wrap(buildAwsValue())
}
object DescribePipelineResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.DescribePipelineResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.DescribePipelineResponse =
      zio.aws.sagemaker.model.DescribePipelineResponse(
        pipelineArn.map(value => value),
        pipelineName.map(value => value),
        pipelineDisplayName.map(value => value),
        pipelineDefinition.map(value => value),
        pipelineDescription.map(value => value),
        roleArn.map(value => value),
        pipelineStatus.map(value => value),
        creationTime.map(value => value),
        lastModifiedTime.map(value => value),
        lastRunTime.map(value => value),
        createdBy.map(value => value.asEditable),
        lastModifiedBy.map(value => value.asEditable),
        parallelismConfiguration.map(value => value.asEditable)
      )
    def pipelineArn: Option[PipelineArn]
    def pipelineName: Option[PipelineName]
    def pipelineDisplayName: Option[PipelineName]
    def pipelineDefinition: Option[PipelineDefinition]
    def pipelineDescription: Option[PipelineDescription]
    def roleArn: Option[RoleArn]
    def pipelineStatus: Option[zio.aws.sagemaker.model.PipelineStatus]
    def creationTime: Option[Timestamp]
    def lastModifiedTime: Option[Timestamp]
    def lastRunTime: Option[Timestamp]
    def createdBy: Option[zio.aws.sagemaker.model.UserContext.ReadOnly]
    def lastModifiedBy: Option[zio.aws.sagemaker.model.UserContext.ReadOnly]
    def parallelismConfiguration
        : Option[zio.aws.sagemaker.model.ParallelismConfiguration.ReadOnly]
    def getPipelineArn: ZIO[Any, AwsError, PipelineArn] =
      AwsError.unwrapOptionField("pipelineArn", pipelineArn)
    def getPipelineName: ZIO[Any, AwsError, PipelineName] =
      AwsError.unwrapOptionField("pipelineName", pipelineName)
    def getPipelineDisplayName: ZIO[Any, AwsError, PipelineName] =
      AwsError.unwrapOptionField("pipelineDisplayName", pipelineDisplayName)
    def getPipelineDefinition: ZIO[Any, AwsError, PipelineDefinition] =
      AwsError.unwrapOptionField("pipelineDefinition", pipelineDefinition)
    def getPipelineDescription: ZIO[Any, AwsError, PipelineDescription] =
      AwsError.unwrapOptionField("pipelineDescription", pipelineDescription)
    def getRoleArn: ZIO[Any, AwsError, RoleArn] =
      AwsError.unwrapOptionField("roleArn", roleArn)
    def getPipelineStatus
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.PipelineStatus] =
      AwsError.unwrapOptionField("pipelineStatus", pipelineStatus)
    def getCreationTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("creationTime", creationTime)
    def getLastModifiedTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastModifiedTime", lastModifiedTime)
    def getLastRunTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastRunTime", lastRunTime)
    def getCreatedBy
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.UserContext.ReadOnly] =
      AwsError.unwrapOptionField("createdBy", createdBy)
    def getLastModifiedBy
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.UserContext.ReadOnly] =
      AwsError.unwrapOptionField("lastModifiedBy", lastModifiedBy)
    def getParallelismConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.ParallelismConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "parallelismConfiguration",
      parallelismConfiguration
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.DescribePipelineResponse
  ) extends zio.aws.sagemaker.model.DescribePipelineResponse.ReadOnly {
    override val pipelineArn: Option[PipelineArn] = scala
      .Option(impl.pipelineArn())
      .map(value => zio.aws.sagemaker.model.primitives.PipelineArn(value))
    override val pipelineName: Option[PipelineName] = scala
      .Option(impl.pipelineName())
      .map(value => zio.aws.sagemaker.model.primitives.PipelineName(value))
    override val pipelineDisplayName: Option[PipelineName] = scala
      .Option(impl.pipelineDisplayName())
      .map(value => zio.aws.sagemaker.model.primitives.PipelineName(value))
    override val pipelineDefinition: Option[PipelineDefinition] = scala
      .Option(impl.pipelineDefinition())
      .map(value =>
        zio.aws.sagemaker.model.primitives.PipelineDefinition(value)
      )
    override val pipelineDescription: Option[PipelineDescription] = scala
      .Option(impl.pipelineDescription())
      .map(value =>
        zio.aws.sagemaker.model.primitives.PipelineDescription(value)
      )
    override val roleArn: Option[RoleArn] = scala
      .Option(impl.roleArn())
      .map(value => zio.aws.sagemaker.model.primitives.RoleArn(value))
    override val pipelineStatus
        : Option[zio.aws.sagemaker.model.PipelineStatus] = scala
      .Option(impl.pipelineStatus())
      .map(value => zio.aws.sagemaker.model.PipelineStatus.wrap(value))
    override val creationTime: Option[Timestamp] = scala
      .Option(impl.creationTime())
      .map(value => zio.aws.sagemaker.model.primitives.Timestamp(value))
    override val lastModifiedTime: Option[Timestamp] = scala
      .Option(impl.lastModifiedTime())
      .map(value => zio.aws.sagemaker.model.primitives.Timestamp(value))
    override val lastRunTime: Option[Timestamp] = scala
      .Option(impl.lastRunTime())
      .map(value => zio.aws.sagemaker.model.primitives.Timestamp(value))
    override val createdBy
        : Option[zio.aws.sagemaker.model.UserContext.ReadOnly] = scala
      .Option(impl.createdBy())
      .map(value => zio.aws.sagemaker.model.UserContext.wrap(value))
    override val lastModifiedBy
        : Option[zio.aws.sagemaker.model.UserContext.ReadOnly] = scala
      .Option(impl.lastModifiedBy())
      .map(value => zio.aws.sagemaker.model.UserContext.wrap(value))
    override val parallelismConfiguration
        : Option[zio.aws.sagemaker.model.ParallelismConfiguration.ReadOnly] =
      scala
        .Option(impl.parallelismConfiguration())
        .map(value =>
          zio.aws.sagemaker.model.ParallelismConfiguration.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.DescribePipelineResponse
  ): zio.aws.sagemaker.model.DescribePipelineResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-sagemaker_3-5.17.295.5-sources.jar: zio/aws/sagemaker/model/DescribePipelineResponse.scala <==
package zio.aws.sagemaker.model
import zio.aws.sagemaker.model.primitives.{
  RoleArn,
  PipelineDescription,
  Timestamp,
  PipelineDefinition,
  PipelineArn,
  PipelineName
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters.*
final case class DescribePipelineResponse(
    pipelineArn: Optional[PipelineArn] = Optional.Absent,
    pipelineName: Optional[PipelineName] = Optional.Absent,
    pipelineDisplayName: Optional[PipelineName] = Optional.Absent,
    pipelineDefinition: Optional[PipelineDefinition] = Optional.Absent,
    pipelineDescription: Optional[PipelineDescription] = Optional.Absent,
    roleArn: Optional[RoleArn] = Optional.Absent,
    pipelineStatus: Optional[zio.aws.sagemaker.model.PipelineStatus] =
      Optional.Absent,
    creationTime: Optional[Timestamp] = Optional.Absent,
    lastModifiedTime: Optional[Timestamp] = Optional.Absent,
    lastRunTime: Optional[Timestamp] = Optional.Absent,
    createdBy: Optional[zio.aws.sagemaker.model.UserContext] = Optional.Absent,
    lastModifiedBy: Optional[zio.aws.sagemaker.model.UserContext] =
      Optional.Absent,
    parallelismConfiguration: Optional[
      zio.aws.sagemaker.model.ParallelismConfiguration
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.DescribePipelineResponse = {
    import DescribePipelineResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.DescribePipelineResponse
      .builder()
      .optionallyWith(
        pipelineArn.map(value => PipelineArn.unwrap(value): java.lang.String)
      )(_.pipelineArn)
      .optionallyWith(
        pipelineName.map(value => PipelineName.unwrap(value): java.lang.String)
      )(_.pipelineName)
      .optionallyWith(
        pipelineDisplayName.map(value =>
          PipelineName.unwrap(value): java.lang.String
        )
      )(_.pipelineDisplayName)
      .optionallyWith(
        pipelineDefinition.map(value =>
          PipelineDefinition.unwrap(value): java.lang.String
        )
      )(_.pipelineDefinition)
      .optionallyWith(
        pipelineDescription.map(value =>
          PipelineDescription.unwrap(value): java.lang.String
        )
      )(_.pipelineDescription)
      .optionallyWith(
        roleArn.map(value => RoleArn.unwrap(value): java.lang.String)
      )(_.roleArn)
      .optionallyWith(pipelineStatus.map(value => value.unwrap))(
        _.pipelineStatus
      )
      .optionallyWith(
        creationTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.creationTime)
      .optionallyWith(
        lastModifiedTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.lastModifiedTime)
      .optionallyWith(
        lastRunTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.lastRunTime)
      .optionallyWith(createdBy.map(value => value.buildAwsValue()))(
        _.createdBy
      )
      .optionallyWith(lastModifiedBy.map(value => value.buildAwsValue()))(
        _.lastModifiedBy
      )
      .optionallyWith(
        parallelismConfiguration.map(value => value.buildAwsValue())
      )(_.parallelismConfiguration)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.DescribePipelineResponse.ReadOnly =
    zio.aws.sagemaker.model.DescribePipelineResponse.wrap(buildAwsValue())
}
object DescribePipelineResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.DescribePipelineResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.DescribePipelineResponse =
      zio.aws.sagemaker.model.DescribePipelineResponse(
        pipelineArn.map(value => value),
        pipelineName.map(value => value),
        pipelineDisplayName.map(value => value),
        pipelineDefinition.map(value => value),
        pipelineDescription.map(value => value),
        roleArn.map(value => value),
        pipelineStatus.map(value => value),
        creationTime.map(value => value),
        lastModifiedTime.map(value => value),
        lastRunTime.map(value => value),
        createdBy.map(value => value.asEditable),
        lastModifiedBy.map(value => value.asEditable),
        parallelismConfiguration.map(value => value.asEditable)
      )
    def pipelineArn: Optional[PipelineArn]
    def pipelineName: Optional[PipelineName]
    def pipelineDisplayName: Optional[PipelineName]
    def pipelineDefinition: Optional[PipelineDefinition]
    def pipelineDescription: Optional[PipelineDescription]
    def roleArn: Optional[RoleArn]
    def pipelineStatus: Optional[zio.aws.sagemaker.model.PipelineStatus]
    def creationTime: Optional[Timestamp]
    def lastModifiedTime: Optional[Timestamp]
    def lastRunTime: Optional[Timestamp]
    def createdBy: Optional[zio.aws.sagemaker.model.UserContext.ReadOnly]
    def lastModifiedBy: Optional[zio.aws.sagemaker.model.UserContext.ReadOnly]
    def parallelismConfiguration
        : Optional[zio.aws.sagemaker.model.ParallelismConfiguration.ReadOnly]
    def getPipelineArn: ZIO[Any, AwsError, PipelineArn] =
      AwsError.unwrapOptionField("pipelineArn", pipelineArn)
    def getPipelineName: ZIO[Any, AwsError, PipelineName] =
      AwsError.unwrapOptionField("pipelineName", pipelineName)
    def getPipelineDisplayName: ZIO[Any, AwsError, PipelineName] =
      AwsError.unwrapOptionField("pipelineDisplayName", pipelineDisplayName)
    def getPipelineDefinition: ZIO[Any, AwsError, PipelineDefinition] =
      AwsError.unwrapOptionField("pipelineDefinition", pipelineDefinition)
    def getPipelineDescription: ZIO[Any, AwsError, PipelineDescription] =
      AwsError.unwrapOptionField("pipelineDescription", pipelineDescription)
    def getRoleArn: ZIO[Any, AwsError, RoleArn] =
      AwsError.unwrapOptionField("roleArn", roleArn)
    def getPipelineStatus
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.PipelineStatus] =
      AwsError.unwrapOptionField("pipelineStatus", pipelineStatus)
    def getCreationTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("creationTime", creationTime)
    def getLastModifiedTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastModifiedTime", lastModifiedTime)
    def getLastRunTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastRunTime", lastRunTime)
    def getCreatedBy
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.UserContext.ReadOnly] =
      AwsError.unwrapOptionField("createdBy", createdBy)
    def getLastModifiedBy
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.UserContext.ReadOnly] =
      AwsError.unwrapOptionField("lastModifiedBy", lastModifiedBy)
    def getParallelismConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.ParallelismConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "parallelismConfiguration",
      parallelismConfiguration
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.DescribePipelineResponse
  ) extends zio.aws.sagemaker.model.DescribePipelineResponse.ReadOnly {
    override val pipelineArn: Optional[PipelineArn] = zio.aws.core.internal
      .optionalFromNullable(impl.pipelineArn())
      .map(value => zio.aws.sagemaker.model.primitives.PipelineArn(value))
    override val pipelineName: Optional[PipelineName] = zio.aws.core.internal
      .optionalFromNullable(impl.pipelineName())
      .map(value => zio.aws.sagemaker.model.primitives.PipelineName(value))
    override val pipelineDisplayName: Optional[PipelineName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.pipelineDisplayName())
        .map(value => zio.aws.sagemaker.model.primitives.PipelineName(value))
    override val pipelineDefinition: Optional[PipelineDefinition] =
      zio.aws.core.internal
        .optionalFromNullable(impl.pipelineDefinition())
        .map(value =>
          zio.aws.sagemaker.model.primitives.PipelineDefinition(value)
        )
    override val pipelineDescription: Optional[PipelineDescription] =
      zio.aws.core.internal
        .optionalFromNullable(impl.pipelineDescription())
        .map(value =>
          zio.aws.sagemaker.model.primitives.PipelineDescription(value)
        )
    override val roleArn: Optional[RoleArn] = zio.aws.core.internal
      .optionalFromNullable(impl.roleArn())
      .map(value => zio.aws.sagemaker.model.primitives.RoleArn(value))
    override val pipelineStatus
        : Optional[zio.aws.sagemaker.model.PipelineStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.pipelineStatus())
        .map(value => zio.aws.sagemaker.model.PipelineStatus.wrap(value))
    override val creationTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.creationTime())
      .map(value => zio.aws.sagemaker.model.primitives.Timestamp(value))
    override val lastModifiedTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.lastModifiedTime())
      .map(value => zio.aws.sagemaker.model.primitives.Timestamp(value))
    override val lastRunTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.lastRunTime())
      .map(value => zio.aws.sagemaker.model.primitives.Timestamp(value))
    override val createdBy
        : Optional[zio.aws.sagemaker.model.UserContext.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.createdBy())
        .map(value => zio.aws.sagemaker.model.UserContext.wrap(value))
    override val lastModifiedBy
        : Optional[zio.aws.sagemaker.model.UserContext.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.lastModifiedBy())
        .map(value => zio.aws.sagemaker.model.UserContext.wrap(value))
    override val parallelismConfiguration
        : Optional[zio.aws.sagemaker.model.ParallelismConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.parallelismConfiguration())
        .map(value =>
          zio.aws.sagemaker.model.ParallelismConfiguration.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.DescribePipelineResponse
  ): zio.aws.sagemaker.model.DescribePipelineResponse.ReadOnly = new Wrapper(
    impl
  )
}
